@@ -1,23 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-addressbook-view.c
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- * Author: Chris Lahey <clahey@ximian.com>
- *         Chris Toshok <toshok@ximian.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Chris Lahey <clahey@ximian.com>
+ *      Chris Toshok <toshok@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -1402,8 +1403,12 @@ search_activated (ESearchBar *esb, EABView *v)
 
 		if (subid) {
 			master_list = get_master_list (FALSE);
-			category_name = g_list_nth_data (master_list, subid-1);
-			view_sexp = g_strdup_printf ("(is \"category_list\" \"%s\")", category_name);
+			if (subid < 3) {
+				view_sexp = g_strdup ("(not (and (exists \"CATEGORIES\") (not (is \"CATEGORIES\" \"\"))))");
+			} else {
+				category_name = g_list_nth_data (master_list, subid-3);
+				view_sexp = g_strdup_printf ("(is \"category_list\" \"%s\")", category_name);
+			}
 			search_query = g_strconcat ("(and ", view_sexp, search_query, ")", NULL);
 			g_free (view_sexp);
 		}
@@ -1478,9 +1483,8 @@ generate_viewoption_menu (EABSearchBarItem *subitems)
                         if (subitems[i].image) {
                                 GtkWidget *image;
 
-                                image = gtk_image_new_from_icon_name (
-                                        subitems[i].image,
-                                        GTK_ICON_SIZE_MENU);
+                                image = gtk_image_new_from_file (
+                                        subitems[i].image);
                                 gtk_image_menu_item_set_image (
                                         GTK_IMAGE_MENU_ITEM (menu_item),
                                         image);
@@ -1518,24 +1522,32 @@ make_suboptions (EABView *view)
 
 	master_list = get_master_list (FALSE);
 	N = g_list_length (master_list);
-	subitems = g_new (EABSearchBarItem, N+2);
+	subitems = g_new (EABSearchBarItem, N+4);
 
 	subitems[0].search.id = 0;
 	subitems[0].search.text = g_strdup (_("Any Category"));
 	subitems[0].image = NULL;
 
+	subitems[1].search.text = g_strdup (_("Unmatched"));
+	subitems[1].search.id = 1;
+	subitems[1].image = NULL;
+
+	subitems[2].search.text = NULL;
+	subitems[2].search.id = 0;
+	subitems[2].image = NULL;
+
 	for (i=0; i<N; ++i) {
 		const char *category = g_list_nth_data (master_list, i);
-		subitems[i+1].search.id = i+1;
-		subitems[i+1].search.text = g_strdup (category);
-		subitems[i+1].image = (char *)e_categories_get_icon_file_for (category);
+		subitems[i+3].search.id = i+3;
+		subitems[i+3].search.text = g_strdup (category);
+		subitems[i+3].image = (char *)e_categories_get_icon_file_for (category);
 	}
 
-	subitems[N+1].search.id = -1;
-	subitems[N+1].search.text = NULL;
-	subitems[N+1].image = NULL;
+	subitems[N+3].search.id = -1;
+	subitems[N+3].search.text = NULL;
+	subitems[N+3].image = NULL;
 
-	qsort (subitems + 1, N, sizeof (subitems[0]), compare_subitems);
+	qsort (subitems + 3, N, sizeof (subitems[0]), compare_subitems);
 	menu = generate_viewoption_menu (subitems);
 	e_search_bar_set_viewoption_menu ((ESearchBar *)view->search, menu);
 
