@@ -1,9 +1,26 @@
-
-/* Copyright (C) 2004 Novell, Inc */
-/* Authors: Michael Zucchi
-            Rodrigo Moya */
-
-/* This file is licensed under the GNU GPL v2 or later */
+/*
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Michael Zucchi <notzed@novell.com>
+ *		Rodrigo Moya <rodrigo@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ */
 
 /* Convert a mail message into a task */
 
@@ -270,7 +287,7 @@ do_mail_to_task (AsyncData *data)
 		e_notice (NULL, GTK_MESSAGE_ERROR, _("Cannot open calendar. %s"), err ? err->message : "");
 	} else if (!e_cal_is_read_only (client, &readonly, &err) || readonly) {
 		if (err)
-			e_notice (NULL, GTK_MESSAGE_ERROR, err->message);
+			e_notice (NULL, GTK_MESSAGE_ERROR, "%s", err->message);
 		else
 			e_notice (NULL, GTK_MESSAGE_ERROR, _("Selected source is read only, thus cannot create task there. Select other source, please."));
 	} else {
