@@ -661,6 +661,7 @@ main (int argc, char **argv)
 		exit (0);
 
 	gnome_sound_init ("localhost");
+	gtk_accel_map_load (e_get_accels_filename ());
 
 	if (!disable_eplugin) {
 		e_plugin_register_type(e_plugin_lib_get_type());
@@ -693,6 +694,8 @@ main (int argc, char **argv)
 
 	bonobo_main ();
 
+	gtk_accel_map_save (e_get_accels_filename ());
+
 	e_icon_factory_shutdown ();
 	g_object_unref (program);
 	gnome_sound_shutdown ();
